summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profile.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/profile.h')
-rw-r--r--chrome/browser/profile.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/profile.h b/chrome/browser/profile.h
index 16455c1..f5e0866 100644
--- a/chrome/browser/profile.h
+++ b/chrome/browser/profile.h
@@ -26,7 +26,6 @@ class BookmarkModel;
class ChromeURLRequestContext;
class DownloadManager;
class ExtensionsService;
-class GreasemonkeyMaster;
class HistoryService;
class NavigationController;
class PrefService;
@@ -36,6 +35,7 @@ class TabRestoreService;
class TemplateURLFetcher;
class TemplateURLModel;
class URLRequestContext;
+class UserScriptMaster;
class VisitedLinkMaster;
class WebDataService;
@@ -109,10 +109,10 @@ class Profile {
// profile. The ExtensionsService is created at startup.
virtual ExtensionsService* GetExtensionsService() = 0;
// Retrieves a pointer to the GreasemonkeyMaster associated with this
// profile. The GreasemonkeyMaster is lazily created the first time
// that this method is called.
- virtual GreasemonkeyMaster* GetGreasemonkeyMaster() = 0;
+ virtual UserScriptMaster* GetUserScriptMaster() = 0;
// Retrieves a pointer to the HistoryService associated with this
// profile. The HistoryService is lazily created the first time
@@ -260,7 +260,7 @@ class ProfileImpl : public Profile,
virtual Profile* GetOffTheRecordProfile();
virtual Profile* GetOriginalProfile();
virtual VisitedLinkMaster* GetVisitedLinkMaster();
- virtual GreasemonkeyMaster* GetGreasemonkeyMaster();
+ virtual UserScriptMaster* GetUserScriptMaster();
virtual ExtensionsService* GetExtensionsService();
virtual HistoryService* GetHistoryService(ServiceAccessType sat);
virtual WebDataService* GetWebDataService(ServiceAccessType sat);
@@ -321,7 +321,7 @@ class ProfileImpl : public Profile,
bool off_the_record_;
scoped_ptr<VisitedLinkMaster> visited_link_master_;
scoped_refptr<ExtensionsService> extensions_service_;
- scoped_refptr<GreasemonkeyMaster> greasemonkey_master_;
+ scoped_refptr<UserScriptMaster> user_script_master_;
scoped_ptr<PrefService> prefs_;
scoped_ptr<TemplateURLFetcher> template_url_fetcher_;
scoped_ptr<TemplateURLModel> template_url_model_;
@@ -109,10 +109,10 @@ class Profile {
// profile. The ExtensionsService is created at startup.
virtual ExtensionsService* GetExtensionsService() = 0;
- // Retrieves a pointer to the GreasemonkeyMaster associated with this
- // profile. The GreasemonkeyMaster is lazily created the first time
+ // Retrieves a pointer to the UserScriptMaster associated with this
+ // profile. The UserScriptMaster is lazily created the first time
// that this method is called.